"""
Files

This module contains actions for transferring files to & from a Windows Server.
"""
from windows_server import client

from .records import WindowsServer
from ._wrappers import winrm


@winrm
def upload_file(
    windows_server: WindowsServer, source: str, destination: str, configuration_name: str = "Microsoft.Powershell"
) -> None:
    r"""Upload a file from the PPA task container to a Windows Server.

This operation will overwrite any existing file with the same destination path.

??? info "Input"

    - __windows_server:__ a [WindowsServer](../inputs_outputs/#windowsserver)

    - __source:__ path of the local file to be uploaded

    - __destination:__ destination path on the Windows Server

    - __configuration_name:__ optional PowerShell configuration endpoint to use when uploading the file


??? success "Output"

    Nothing is outputted by this action.

??? example

    ```YAML linenums="1"
    - windows_server.files.upload_file:
        source: "./report.csv"
        destination: "C:\Users\example.user\report.csv"
      load:
        windows_server: windows_server
    ```
    """
    return client.upload_file(windows_server, source=source, destination=destination, configuration_name=configuration_name)
